@@ -1,8 +1,8 @@
 use lazy_static::lazy_static;
 #[cfg(feature = "pyo3")]
 use pyo3::{
-    basic::CompareOp, exceptions::PyValueError, pyclass, pymethods, IntoPy, PyObject, PyResult,
-    Python,
+    basic::CompareOp, exceptions::PyValueError, pyclass, pymethods, FromPyObject, IntoPy, PyAny,
+    PyObject, PyResult, Python,
 };
 use regex::Captures;
 use regex::Regex;
@@ -21,7 +21,7 @@ use tracing::warn;
 
 /// A regex copied from <https://peps.python.org/pep-0440/#appendix-b-parsing-version-strings-with-regular-expressions>,
 /// updated to support stars for version ranges
-pub(crate) const VERSION_RE_INNER: &str = r#"
+pub(crate) const VERSION_RE_INNER: &str = r"
 (?:
     (?:v?)                                            # <https://peps.python.org/pep-0440/#preceding-v-character>
     (?:(?P<epoch>[0-9]+)!)?                           # epoch
@@ -51,7 +51,7 @@ pub(crate) const VERSION_RE_INNER: &str = r#"
 )
 (?:\+(?P<local>[a-z0-9]+(?:[-_\.][a-z0-9]+)*))?       # local version
 (?P<trailing_dot_star>\.\*)?                          # allow for version matching `.*`
-"#;
+";
 
 lazy_static! {
     /// Matches a python version, such as `1.19.a1`. Based on the PEP 440 regex
@@ -304,6 +304,13 @@ impl IntoPy<PyObject> for Version {
     }
 }
 
+#[cfg(feature = "pyo3")]
+impl<'source> FromPyObject<'source> for Version {
+    fn extract(ob: &'source PyAny) -> PyResult<Self> {
+        Ok(ob.extract::<PyVersion>()?.0)
+    }
+}
+
 /// Workaround for https://github.com/PyO3/pyo3/pull/2786
 #[cfg(feature = "pyo3")]
 #[derive(Clone, Debug)]
@@ -819,6 +826,8 @@ impl Version {
 
 #[cfg(test)]
 mod test {
+    #[cfg(feature = "pyo3")]
+    use pyo3::pyfunction;
     use std::str::FromStr;
 
     use crate::{Version, VersionSpecifier};
@@ -1169,4 +1178,10 @@ mod test {
             "You can't have both a trailing `.*` and a local version"
         );
     }
+
+    #[cfg(feature = "pyo3")]
+    #[pyfunction]
+    fn _convert_in_and_out(version: Version) -> Version {
+        version
+    }
 }
